@@ -680,6 +680,11 @@ class ConsumerThread(Thread):
                                    password=self.amqp_credentials.password,
                                    virtual_host=self.amqp_credentials.vhost,
                                    ssl=self.amqp_credentials.ssl)
+                                   
+                self.consumer = Consumer(connection=self.amqpconn,
+                                 queue=self.client_id + '_client_queue',
+                                 exchange=self.server_id + '_client_exchange',
+                                 routing_key=self.client_id + '_client_routing_key')
 #===========================================================================
 class PublisherThread(Thread):
     """
@@ -775,6 +780,11 @@ class PublisherThread(Thread):
                                    password=self.amqp_credentials.password,
                                    virtual_host=self.amqp_credentials.vhost,
                                    ssl=self.amqp_credentials.ssl)
+
+                    self.publisher = Publisher(connection=self.amqpconn,
+                                   exchange=self.server_id + "_server_exchange",
+                                   routing_key=self.server_id + "_server_routing_key",
+                                   serializer=self.serializer)
                 except Exception:
                     logger.exeption('Exception: During connection a broken AMQP Connection')
     
