@@ -251,6 +251,11 @@ class QAMServer:
                                    password=self.amqp_credentials.password,
                                    virtual_host=self.amqp_credentials.vhost,
                                    ssl=self.amqp_credentials.ssl)
+                                   
+            self.consumer = Consumer(connection=self.amqpconn,
+                             queue=self.server_id + '_server_queue',
+                             exchange=self.server_id + '_server_exchange',
+                             routing_key=self.server_id + '_server_routing_key')
 
     self.finished = True
 
